# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TNCommandArchives.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import numbers_parser.generated.TSPMessages_pb2 as TSPMessages__pb2
import numbers_parser.generated.TSKArchives_pb2 as TSKArchives__pb2
import numbers_parser.generated.TSCHArchives_pb2 as TSCHArchives__pb2
import numbers_parser.generated.TSCHCommandArchives_pb2 as TSCHCommandArchives__pb2
import numbers_parser.generated.TSCEArchives_pb2 as TSCEArchives__pb2
import numbers_parser.generated.TSSArchives_pb2 as TSSArchives__pb2
import numbers_parser.generated.TSDArchives_pb2 as TSDArchives__pb2
import numbers_parser.generated.TSDCommandArchives_pb2 as TSDCommandArchives__pb2
import numbers_parser.generated.TSWPArchives_pb2 as TSWPArchives__pb2
import numbers_parser.generated.TSAArchives_pb2 as TSAArchives__pb2
import numbers_parser.generated.TSTArchives_pb2 as TSTArchives__pb2
import numbers_parser.generated.TNArchives_pb2 as TNArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TNCommandArchives.proto',
  package='TN',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17TNCommandArchives.proto\x12\x02TN\x1a\x11TSPMessages.proto\x1a\x11TSKArchives.proto\x1a\x12TSCHArchives.proto\x1a\x19TSCHCommandArchives.proto\x1a\x12TSCEArchives.proto\x1a\x11TSSArchives.proto\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x12TSWPArchives.proto\x1a\x11TSAArchives.proto\x1a\x11TSTArchives.proto\x1a\x10TNArchives.proto\"\xda\x01\n#CommandFormChooseTargetTableArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08table_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12$\n\x11previous_table_id\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12\x12\n\nsheet_name\x18\x04 \x02(\t\x12\x1b\n\x13previous_sheet_name\x18\x05 \x01(\t\x12\x1b\n\x08sheet_id\x18\x06 \x02(\x0b\x32\t.TSP.UUID\"\xe1\x03\n\"CommandSheetInsertDrawablesArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08sheet_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12!\n\tdrawables\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12*\n\targs_list\x18\x04 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x12\x10\n\x08\x66orPaste\x18\x05 \x01(\x08\x12%\n\x12\x63ustom_format_keys\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12,\n\x14\x64rawable_undo_object\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\x12\x38\n formula_rewrite_command_for_undo\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12*\n\"saved_next_untitled_resolver_index\x18\n \x01(\r\x12\x36\n#chart_entity_uid_for_backing_tables\x18\x0b \x03(\x0b\x32\t.TSP.UUID\x12&\n\x0e\x62\x61\x63king_tables\x18\x0c \x03(\x0b\x32\x0e.TSP.Reference\"\x96\x02\n\"CommandSheetRemoveDrawablesArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08sheet_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12-\n\targs_list\x18\x03 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x12!\n\tdrawables\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\x12\x36\n#chart_entity_uid_for_backing_tables\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12%\n\x12\x62\x61\x63king_table_uids\x18\x07 \x03(\x0b\x32\t.TSP.UUID\"\x9a\x01\n%CommandSheetMoveDrawableZOrderArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08sheet_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x30\n\targs_list\x18\x03 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgs\"\xdc\x02\n!CommandDocumentInsertSheetArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n\x08\x61rgsList\x18\x02 \x03(\x0b\x32\x17.TSK.AddIdOperationArgs\x12\x1e\n\x06sheets\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x19\x61llowSameSheetNameAsForms\x18\x04 \x01(\x08\x12%\n\x12\x63ustom_format_keys\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12,\n\x14\x64rawable_undo_object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12=\n\x0esheet_uistates\x18\x07 \x03(\x0b\x32%.TN.UUIDSheetUIStateDictionaryArchive\x12\x11\n\tfor_paste\x18\x08 \x01(\x08\"\xfd\x01\n!CommandDocumentRemoveSheetArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12,\n\x08\x61rgsList\x18\x02 \x03(\x0b\x32\x1a.TSK.RemoveIdOperationArgs\x12\x1e\n\x06sheets\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\x10\n\x08rescueId\x18\x04 \x02(\t\x12=\n\x0esheet_uistates\x18\x05 \x03(\x0b\x32%.TN.UUIDSheetUIStateDictionaryArchive\x12\x15\n\ris_undo_paste\x18\x06 \x01(\x08\"y\n\"CommandDocumentReorderSheetArchive\x12/\n\x08\x61rgsList\x18\x01 \x03(\x0b\x32\x1d.TSK.RearrangeIdOperationArgs\x12\"\n\x05super\x18\x02 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x80\x01\n\x1a\x43ommandSetSheetNameArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x0f\n\x07newname\x18\x02 \x02(\t\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x0f\n\x07oldname\x18\x04 \x01(\t\"\xb3\x01\n)CommandSetSheetShouldPrintCommentsArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12!\n\x19new_should_print_comments\x18\x02 \x02(\x08\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12!\n\x19old_should_print_comments\x18\x04 \x02(\x08\"\xc1\x01\n\x1f\x43ommandSetSheetDirectionArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12-\n\x0cnewDirection\x18\x02 \x02(\x0e\x32\x17.TN.PageLayoutDirection\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12-\n\x0coldDirection\x18\x04 \x01(\x0e\x32\x17.TN.PageLayoutDirection\"\xb5\x01\n CommandSetPageOrientationArchive\x12$\n\x1cin_portrait_page_orientation\x18\x01 \x02(\x08\x12\x1c\n\tsheet_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x03 \x02(\x0b\x32\x13.TSK.CommandArchive\x12)\n!prev_in_portrait_page_orientation\x18\x04 \x02(\x08\"\x85\x01\n%CommandSetShowPageNumbersValueArchive\x12\x19\n\x11show_page_numbers\x18\x01 \x02(\x08\x12\x1d\n\x05sheet\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\x05super\x18\x03 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x8b\x01\n&CommandSetRepeatingHeadersValueArchive\x12\x1e\n\x16show_repeating_headers\x18\x01 \x02(\x08\x12\x1d\n\x05sheet\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\x05super\x18\x03 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xad\x01\n\x1d\x43ommandSetContentScaleArchive\x12\x19\n\x11old_content_scale\x18\x02 \x01(\x02\x12\x15\n\rcontent_scale\x18\x03 \x02(\x02\x12\x1c\n\tsheet_uid\x18\x04 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x05 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x18\n\x10toggled_auto_fit\x18\x06 \x02(\x08\"\xa9\x01\n\x1b\x43ommandSetDocumentPaperSize\x12\x10\n\x08paper_id\x18\x01 \x02(\t\x12\x1c\n\tpage_size\x18\x02 \x02(\x0b\x32\t.TSP.Size\x12\"\n\x05super\x18\x03 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x14\n\x0cold_paper_id\x18\x04 \x02(\t\x12 \n\rold_page_size\x18\x05 \x02(\x0b\x32\t.TSP.Size\"I\n#CommandEnterPrintPreviewModeArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"H\n\"CommandExitPrintPreviewModeArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xc9\x01\n\x1f\x43ommandSetPrinterMarginsArchive\x12\x31\n\x11new_print_margins\x18\x01 \x02(\x0b\x32\x16.TSD.EdgeInsetsArchive\x12\x31\n\x11old_print_margins\x18\x02 \x01(\x0b\x32\x16.TSD.EdgeInsetsArchive\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x04 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x9f\x01\n!CommandSetPrintBackgroundsArchive\x12\x1c\n\tsheet_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x19\n\x11print_backgrounds\x18\x02 \x02(\x08\x12\x1d\n\x15old_print_backgrounds\x18\x03 \x02(\x08\x12\"\n\x05super\x18\x04 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xc7\x01\n#CommandSetHeaderFooterInsetsArchive\x12\x18\n\x10old_header_inset\x18\x01 \x01(\x02\x12\x18\n\x10old_footer_inset\x18\x02 \x01(\x02\x12\x14\n\x0cheader_inset\x18\x03 \x02(\x02\x12\x14\n\x0c\x66ooter_inset\x18\x04 \x02(\x02\x12\x1c\n\tsheet_uid\x18\x05 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x06 \x02(\x0b\x32\x13.TSK.CommandArchive\"\x8a\x01\n\x1a\x43ommandSetPageOrderArchive\x12\x16\n\x0eold_page_order\x18\x01 \x02(\r\x12\x12\n\npage_order\x18\x02 \x02(\r\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x04 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xb0\x01\n%CommandSetUsingStartPageNumberArchive\x12\x1f\n\x17using_start_page_number\x18\x01 \x02(\x08\x12\x1c\n\tsheet_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x03 \x02(\x0b\x32\x13.TSK.CommandArchive\x12$\n\x1cprev_using_start_page_number\x18\x04 \x02(\x08\"\x9e\x01\n CommandSetStartPageNumberArchive\x12\x1d\n\x15old_start_page_number\x18\x01 \x02(\x05\x12\x19\n\x11start_page_number\x18\x02 \x02(\x05\x12\x1c\n\tsheet_uid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x05super\x18\x04 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xb8\x01\n\'CommandReorderSidebarItemChildrenAchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05sheet\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12$\n\x0cold_children\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12$\n\x0cnew_children\x18\x04 \x03(\x0b\x32\x0e.TSP.Reference\"\xc0\x02\n#CommandChartMediatorSetEditingState\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x35\n\x0cold_formulas\x18\x03 \x01(\x0b\x32\x1f.TN.ChartMediatorFormulaStorage\x12\x35\n\x0cnew_formulas\x18\x04 \x01(\x0b\x32\x1f.TN.ChartMediatorFormulaStorage\x12\x15\n\rold_direction\x18\x05 \x01(\x05\x12\x15\n\rnew_direction\x18\x06 \x01(\x05\x12\x1a\n\x12old_scatter_format\x18\x07 \x01(\x05\x12\x1a\n\x12new_scatter_format\x18\x08 \x01(\x05\x12\x1b\n\x13\x66or_formula_rewrite\x18\t \x01(\x08\"\xbc\x01\n$CommandChartMediatorSetGridDirection\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x15\n\rold_direction\x18\x02 \x02(\r\x12\x15\n\rnew_direction\x18\x03 \x02(\r\x12<\n\x13old_formula_storage\x18\x04 \x01(\x0b\x32\x1f.TN.ChartMediatorFormulaStorage\"\xdc\x02\n\"CommandChartMediatorSetSeriesOrder\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1c\n\tseries_id\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12&\n\x13preceding_series_id\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12$\n\x11inverse_series_id\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12.\n\x1binverse_preceding_series_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12\x1a\n\x12undo_current_index\x18\x06 \x02(\x05\x12\x16\n\x0eundo_new_index\x18\x07 \x02(\x05\x12<\n\x13old_formula_storage\x18\x08 \x01(\x0b\x32\x1f.TN.ChartMediatorFormulaStorage\"r\n)CommandChartMediatorUpdateForEntityDelete\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1b\n\x03\x63md\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\"\xe7\x01\n\x1e\x43ommandChartMediatorSetFormula\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1e\n\x16model_update_data_type\x18\x02 \x02(\x05\x12&\n\x08\x66ormulae\x18\x03 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12*\n\x0cold_formulae\x18\x04 \x03(\x0b\x32\x14.TSCE.FormulaArchive\x12\x14\n\x0cseries_index\x18\x05 \x02(\r\x12\x11\n\taxis_type\x18\x06 \x02(\x05\"\xaf\x01\n$CommandSheetSetBackgroundFillArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08sheet_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x08new_fill\x18\x03 \x02(\x0b\x32\x10.TSD.FillArchive\x12\"\n\x08old_fill\x18\x04 \x02(\x0b\x32\x10.TSD.FillArchive\"\xac\x01\n\x1b\x43ommandSheetSetStyleArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1b\n\x08sheet_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12#\n\x0bsheet_style\x18\x03 \x02(\x0b\x32\x0e.TSP.Reference\x12\'\n\x0fold_sheet_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"Q\n#DocumentSelectionTransformerArchive\x12*\n\x12\x64ocument_selection\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"T\n SheetSelectionTransformerArchive\x12\x1d\n\nsheet_uuid\x18\x01 \x01(\x0b\x32\t.TSP.UUID\x12\x11\n\tpaginated\x18\x02 \x02(\x08\"z\n$FormSheetSelectionTransformerArchive\x12\x33\n\x05super\x18\x01 \x02(\x0b\x32$.TN.SheetSelectionTransformerArchive\x12\x1d\n\ntable_uuid\x18\x02 \x01(\x0b\x32\t.TSP.UUID\"\xa6\x01\n!CanvasSelectionTransformerArchive\x12P\n\x12transformer_helper\x18\x01 \x02(\x0b\x32\x34.TSD.InfoCollectionSelectionTransformerHelperArchive\x12/\n\x18header_storage_uuid_path\x18\x02 \x01(\x0b\x32\r.TSP.UUIDPath\"-\n+FormTableChooserSelectionTransformerArchive\"\x96\x01\n&FormBuilderSelectionTransformerArchive\x12\x1d\n\ntable_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12&\n\x13viewing_record_uuid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12%\n\x12\x65\x64iting_field_uuid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\"\x85\x01\n%FormViewerSelectionTransformerArchive\x12\x1d\n\ntable_uuid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0brecord_uuid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\nfield_uuid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\"5\n\x16SheetChangeBaseArchive\x12\x1b\n\x08sheet_id\x18\x01 \x02(\x0b\x32\t.TSP.UUID\"\\\n\x1bSheetChangeSheetNameArchive\x12)\n\x05super\x18\x01 \x02(\x0b\x32\x1a.TN.SheetChangeBaseArchive\x12\x12\n\nsheet_name\x18\x02 \x02(\t\"~\n CommandInducedSheetChangeArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x36\n\rsheet_changes\x18\x02 \x03(\x0b\x32\x1f.TN.SheetChangeSheetNameArchive'
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSCHArchives__pb2.DESCRIPTOR,TSCHCommandArchives__pb2.DESCRIPTOR,TSCEArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,TSAArchives__pb2.DESCRIPTOR,TSTArchives__pb2.DESCRIPTOR,TNArchives__pb2.DESCRIPTOR,])




_COMMANDFORMCHOOSETARGETTABLEARCHIVE = _descriptor.Descriptor(
  name='CommandFormChooseTargetTableArchive',
  full_name='TN.CommandFormChooseTargetTableArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandFormChooseTargetTableArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_id', full_name='TN.CommandFormChooseTargetTableArchive.table_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_table_id', full_name='TN.CommandFormChooseTargetTableArchive.previous_table_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_name', full_name='TN.CommandFormChooseTargetTableArchive.sheet_name', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_sheet_name', full_name='TN.CommandFormChooseTargetTableArchive.previous_sheet_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandFormChooseTargetTableArchive.sheet_id', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=495,
)


_COMMANDSHEETINSERTDRAWABLESARCHIVE = _descriptor.Descriptor(
  name='CommandSheetInsertDrawablesArchive',
  full_name='TN.CommandSheetInsertDrawablesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSheetInsertDrawablesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandSheetInsertDrawablesArchive.sheet_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TN.CommandSheetInsertDrawablesArchive.drawables', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TN.CommandSheetInsertDrawablesArchive.args_list', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forPaste', full_name='TN.CommandSheetInsertDrawablesArchive.forPaste', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TN.CommandSheetInsertDrawablesArchive.custom_format_keys', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drawable_undo_object', full_name='TN.CommandSheetInsertDrawablesArchive.drawable_undo_object', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formula_rewrite_command_for_undo', full_name='TN.CommandSheetInsertDrawablesArchive.formula_rewrite_command_for_undo', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='saved_next_untitled_resolver_index', full_name='TN.CommandSheetInsertDrawablesArchive.saved_next_untitled_resolver_index', index=8,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_entity_uid_for_backing_tables', full_name='TN.CommandSheetInsertDrawablesArchive.chart_entity_uid_for_backing_tables', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backing_tables', full_name='TN.CommandSheetInsertDrawablesArchive.backing_tables', index=10,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=979,
)


_COMMANDSHEETREMOVEDRAWABLESARCHIVE = _descriptor.Descriptor(
  name='CommandSheetRemoveDrawablesArchive',
  full_name='TN.CommandSheetRemoveDrawablesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSheetRemoveDrawablesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandSheetRemoveDrawablesArchive.sheet_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TN.CommandSheetRemoveDrawablesArchive.args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TN.CommandSheetRemoveDrawablesArchive.drawables', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_entity_uid_for_backing_tables', full_name='TN.CommandSheetRemoveDrawablesArchive.chart_entity_uid_for_backing_tables', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backing_table_uids', full_name='TN.CommandSheetRemoveDrawablesArchive.backing_table_uids', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=982,
  serialized_end=1260,
)


_COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE = _descriptor.Descriptor(
  name='CommandSheetMoveDrawableZOrderArchive',
  full_name='TN.CommandSheetMoveDrawableZOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSheetMoveDrawableZOrderArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandSheetMoveDrawableZOrderArchive.sheet_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args_list', full_name='TN.CommandSheetMoveDrawableZOrderArchive.args_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1263,
  serialized_end=1417,
)


_COMMANDDOCUMENTINSERTSHEETARCHIVE = _descriptor.Descriptor(
  name='CommandDocumentInsertSheetArchive',
  full_name='TN.CommandDocumentInsertSheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandDocumentInsertSheetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='argsList', full_name='TN.CommandDocumentInsertSheetArchive.argsList', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheets', full_name='TN.CommandDocumentInsertSheetArchive.sheets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowSameSheetNameAsForms', full_name='TN.CommandDocumentInsertSheetArchive.allowSameSheetNameAsForms', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_format_keys', full_name='TN.CommandDocumentInsertSheetArchive.custom_format_keys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drawable_undo_object', full_name='TN.CommandDocumentInsertSheetArchive.drawable_undo_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uistates', full_name='TN.CommandDocumentInsertSheetArchive.sheet_uistates', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for_paste', full_name='TN.CommandDocumentInsertSheetArchive.for_paste', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1420,
  serialized_end=1768,
)


_COMMANDDOCUMENTREMOVESHEETARCHIVE = _descriptor.Descriptor(
  name='CommandDocumentRemoveSheetArchive',
  full_name='TN.CommandDocumentRemoveSheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandDocumentRemoveSheetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='argsList', full_name='TN.CommandDocumentRemoveSheetArchive.argsList', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheets', full_name='TN.CommandDocumentRemoveSheetArchive.sheets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rescueId', full_name='TN.CommandDocumentRemoveSheetArchive.rescueId', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uistates', full_name='TN.CommandDocumentRemoveSheetArchive.sheet_uistates', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_undo_paste', full_name='TN.CommandDocumentRemoveSheetArchive.is_undo_paste', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1771,
  serialized_end=2024,
)


_COMMANDDOCUMENTREORDERSHEETARCHIVE = _descriptor.Descriptor(
  name='CommandDocumentReorderSheetArchive',
  full_name='TN.CommandDocumentReorderSheetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='argsList', full_name='TN.CommandDocumentReorderSheetArchive.argsList', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandDocumentReorderSheetArchive.super', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2147,
)


_COMMANDSETSHEETNAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetSheetNameArchive',
  full_name='TN.CommandSetSheetNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetSheetNameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newname', full_name='TN.CommandSetSheetNameArchive.newname', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetSheetNameArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oldname', full_name='TN.CommandSetSheetNameArchive.oldname', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2150,
  serialized_end=2278,
)


_COMMANDSETSHEETSHOULDPRINTCOMMENTSARCHIVE = _descriptor.Descriptor(
  name='CommandSetSheetShouldPrintCommentsArchive',
  full_name='TN.CommandSetSheetShouldPrintCommentsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetSheetShouldPrintCommentsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_should_print_comments', full_name='TN.CommandSetSheetShouldPrintCommentsArchive.new_should_print_comments', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetSheetShouldPrintCommentsArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_should_print_comments', full_name='TN.CommandSetSheetShouldPrintCommentsArchive.old_should_print_comments', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2281,
  serialized_end=2460,
)


_COMMANDSETSHEETDIRECTIONARCHIVE = _descriptor.Descriptor(
  name='CommandSetSheetDirectionArchive',
  full_name='TN.CommandSetSheetDirectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetSheetDirectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='newDirection', full_name='TN.CommandSetSheetDirectionArchive.newDirection', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetSheetDirectionArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oldDirection', full_name='TN.CommandSetSheetDirectionArchive.oldDirection', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2463,
  serialized_end=2656,
)


_COMMANDSETPAGEORIENTATIONARCHIVE = _descriptor.Descriptor(
  name='CommandSetPageOrientationArchive',
  full_name='TN.CommandSetPageOrientationArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='in_portrait_page_orientation', full_name='TN.CommandSetPageOrientationArchive.in_portrait_page_orientation', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetPageOrientationArchive.sheet_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetPageOrientationArchive.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_in_portrait_page_orientation', full_name='TN.CommandSetPageOrientationArchive.prev_in_portrait_page_orientation', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2840,
)


_COMMANDSETSHOWPAGENUMBERSVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandSetShowPageNumbersValueArchive',
  full_name='TN.CommandSetShowPageNumbersValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='show_page_numbers', full_name='TN.CommandSetShowPageNumbersValueArchive.show_page_numbers', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.CommandSetShowPageNumbersValueArchive.sheet', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetShowPageNumbersValueArchive.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2843,
  serialized_end=2976,
)


_COMMANDSETREPEATINGHEADERSVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandSetRepeatingHeadersValueArchive',
  full_name='TN.CommandSetRepeatingHeadersValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='show_repeating_headers', full_name='TN.CommandSetRepeatingHeadersValueArchive.show_repeating_headers', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.CommandSetRepeatingHeadersValueArchive.sheet', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetRepeatingHeadersValueArchive.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2979,
  serialized_end=3118,
)


_COMMANDSETCONTENTSCALEARCHIVE = _descriptor.Descriptor(
  name='CommandSetContentScaleArchive',
  full_name='TN.CommandSetContentScaleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_content_scale', full_name='TN.CommandSetContentScaleArchive.old_content_scale', index=0,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_scale', full_name='TN.CommandSetContentScaleArchive.content_scale', index=1,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetContentScaleArchive.sheet_uid', index=2,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetContentScaleArchive.super', index=3,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toggled_auto_fit', full_name='TN.CommandSetContentScaleArchive.toggled_auto_fit', index=4,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3121,
  serialized_end=3294,
)


_COMMANDSETDOCUMENTPAPERSIZE = _descriptor.Descriptor(
  name='CommandSetDocumentPaperSize',
  full_name='TN.CommandSetDocumentPaperSize',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='paper_id', full_name='TN.CommandSetDocumentPaperSize.paper_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='TN.CommandSetDocumentPaperSize.page_size', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetDocumentPaperSize.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_paper_id', full_name='TN.CommandSetDocumentPaperSize.old_paper_id', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_page_size', full_name='TN.CommandSetDocumentPaperSize.old_page_size', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3297,
  serialized_end=3466,
)


_COMMANDENTERPRINTPREVIEWMODEARCHIVE = _descriptor.Descriptor(
  name='CommandEnterPrintPreviewModeArchive',
  full_name='TN.CommandEnterPrintPreviewModeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandEnterPrintPreviewModeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3468,
  serialized_end=3541,
)


_COMMANDEXITPRINTPREVIEWMODEARCHIVE = _descriptor.Descriptor(
  name='CommandExitPrintPreviewModeArchive',
  full_name='TN.CommandExitPrintPreviewModeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandExitPrintPreviewModeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3543,
  serialized_end=3615,
)


_COMMANDSETPRINTERMARGINSARCHIVE = _descriptor.Descriptor(
  name='CommandSetPrinterMarginsArchive',
  full_name='TN.CommandSetPrinterMarginsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_print_margins', full_name='TN.CommandSetPrinterMarginsArchive.new_print_margins', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_print_margins', full_name='TN.CommandSetPrinterMarginsArchive.old_print_margins', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetPrinterMarginsArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetPrinterMarginsArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3618,
  serialized_end=3819,
)


_COMMANDSETPRINTBACKGROUNDSARCHIVE = _descriptor.Descriptor(
  name='CommandSetPrintBackgroundsArchive',
  full_name='TN.CommandSetPrintBackgroundsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetPrintBackgroundsArchive.sheet_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='print_backgrounds', full_name='TN.CommandSetPrintBackgroundsArchive.print_backgrounds', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_print_backgrounds', full_name='TN.CommandSetPrintBackgroundsArchive.old_print_backgrounds', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetPrintBackgroundsArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3822,
  serialized_end=3981,
)


_COMMANDSETHEADERFOOTERINSETSARCHIVE = _descriptor.Descriptor(
  name='CommandSetHeaderFooterInsetsArchive',
  full_name='TN.CommandSetHeaderFooterInsetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_header_inset', full_name='TN.CommandSetHeaderFooterInsetsArchive.old_header_inset', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_footer_inset', full_name='TN.CommandSetHeaderFooterInsetsArchive.old_footer_inset', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_inset', full_name='TN.CommandSetHeaderFooterInsetsArchive.header_inset', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer_inset', full_name='TN.CommandSetHeaderFooterInsetsArchive.footer_inset', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetHeaderFooterInsetsArchive.sheet_uid', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetHeaderFooterInsetsArchive.super', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3984,
  serialized_end=4183,
)


_COMMANDSETPAGEORDERARCHIVE = _descriptor.Descriptor(
  name='CommandSetPageOrderArchive',
  full_name='TN.CommandSetPageOrderArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_page_order', full_name='TN.CommandSetPageOrderArchive.old_page_order', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_order', full_name='TN.CommandSetPageOrderArchive.page_order', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetPageOrderArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetPageOrderArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4186,
  serialized_end=4324,
)


_COMMANDSETUSINGSTARTPAGENUMBERARCHIVE = _descriptor.Descriptor(
  name='CommandSetUsingStartPageNumberArchive',
  full_name='TN.CommandSetUsingStartPageNumberArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='using_start_page_number', full_name='TN.CommandSetUsingStartPageNumberArchive.using_start_page_number', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetUsingStartPageNumberArchive.sheet_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetUsingStartPageNumberArchive.super', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prev_using_start_page_number', full_name='TN.CommandSetUsingStartPageNumberArchive.prev_using_start_page_number', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4327,
  serialized_end=4503,
)


_COMMANDSETSTARTPAGENUMBERARCHIVE = _descriptor.Descriptor(
  name='CommandSetStartPageNumberArchive',
  full_name='TN.CommandSetStartPageNumberArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='old_start_page_number', full_name='TN.CommandSetStartPageNumberArchive.old_start_page_number', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_page_number', full_name='TN.CommandSetStartPageNumberArchive.start_page_number', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_uid', full_name='TN.CommandSetStartPageNumberArchive.sheet_uid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSetStartPageNumberArchive.super', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4506,
  serialized_end=4664,
)


_COMMANDREORDERSIDEBARITEMCHILDRENACHIVE = _descriptor.Descriptor(
  name='CommandReorderSidebarItemChildrenAchive',
  full_name='TN.CommandReorderSidebarItemChildrenAchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandReorderSidebarItemChildrenAchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet', full_name='TN.CommandReorderSidebarItemChildrenAchive.sheet', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_children', full_name='TN.CommandReorderSidebarItemChildrenAchive.old_children', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_children', full_name='TN.CommandReorderSidebarItemChildrenAchive.new_children', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4667,
  serialized_end=4851,
)


_COMMANDCHARTMEDIATORSETEDITINGSTATE = _descriptor.Descriptor(
  name='CommandChartMediatorSetEditingState',
  full_name='TN.CommandChartMediatorSetEditingState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandChartMediatorSetEditingState.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_formulas', full_name='TN.CommandChartMediatorSetEditingState.old_formulas', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_formulas', full_name='TN.CommandChartMediatorSetEditingState.new_formulas', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_direction', full_name='TN.CommandChartMediatorSetEditingState.old_direction', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_direction', full_name='TN.CommandChartMediatorSetEditingState.new_direction', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_scatter_format', full_name='TN.CommandChartMediatorSetEditingState.old_scatter_format', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_scatter_format', full_name='TN.CommandChartMediatorSetEditingState.new_scatter_format', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='for_formula_rewrite', full_name='TN.CommandChartMediatorSetEditingState.for_formula_rewrite', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4854,
  serialized_end=5174,
)


_COMMANDCHARTMEDIATORSETGRIDDIRECTION = _descriptor.Descriptor(
  name='CommandChartMediatorSetGridDirection',
  full_name='TN.CommandChartMediatorSetGridDirection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandChartMediatorSetGridDirection.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_direction', full_name='TN.CommandChartMediatorSetGridDirection.old_direction', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_direction', full_name='TN.CommandChartMediatorSetGridDirection.new_direction', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_formula_storage', full_name='TN.CommandChartMediatorSetGridDirection.old_formula_storage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5177,
  serialized_end=5365,
)


_COMMANDCHARTMEDIATORSETSERIESORDER = _descriptor.Descriptor(
  name='CommandChartMediatorSetSeriesOrder',
  full_name='TN.CommandChartMediatorSetSeriesOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandChartMediatorSetSeriesOrder.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series_id', full_name='TN.CommandChartMediatorSetSeriesOrder.series_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preceding_series_id', full_name='TN.CommandChartMediatorSetSeriesOrder.preceding_series_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_series_id', full_name='TN.CommandChartMediatorSetSeriesOrder.inverse_series_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inverse_preceding_series_id', full_name='TN.CommandChartMediatorSetSeriesOrder.inverse_preceding_series_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo_current_index', full_name='TN.CommandChartMediatorSetSeriesOrder.undo_current_index', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='undo_new_index', full_name='TN.CommandChartMediatorSetSeriesOrder.undo_new_index', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_formula_storage', full_name='TN.CommandChartMediatorSetSeriesOrder.old_formula_storage', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5368,
  serialized_end=5716,
)


_COMMANDCHARTMEDIATORUPDATEFORENTITYDELETE = _descriptor.Descriptor(
  name='CommandChartMediatorUpdateForEntityDelete',
  full_name='TN.CommandChartMediatorUpdateForEntityDelete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandChartMediatorUpdateForEntityDelete.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='TN.CommandChartMediatorUpdateForEntityDelete.cmd', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5718,
  serialized_end=5832,
)


_COMMANDCHARTMEDIATORSETFORMULA = _descriptor.Descriptor(
  name='CommandChartMediatorSetFormula',
  full_name='TN.CommandChartMediatorSetFormula',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandChartMediatorSetFormula.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_update_data_type', full_name='TN.CommandChartMediatorSetFormula.model_update_data_type', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formulae', full_name='TN.CommandChartMediatorSetFormula.formulae', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_formulae', full_name='TN.CommandChartMediatorSetFormula.old_formulae', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series_index', full_name='TN.CommandChartMediatorSetFormula.series_index', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='TN.CommandChartMediatorSetFormula.axis_type', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5835,
  serialized_end=6066,
)


_COMMANDSHEETSETBACKGROUNDFILLARCHIVE = _descriptor.Descriptor(
  name='CommandSheetSetBackgroundFillArchive',
  full_name='TN.CommandSheetSetBackgroundFillArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSheetSetBackgroundFillArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandSheetSetBackgroundFillArchive.sheet_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_fill', full_name='TN.CommandSheetSetBackgroundFillArchive.new_fill', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_fill', full_name='TN.CommandSheetSetBackgroundFillArchive.old_fill', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6069,
  serialized_end=6244,
)


_COMMANDSHEETSETSTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandSheetSetStyleArchive',
  full_name='TN.CommandSheetSetStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandSheetSetStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.CommandSheetSetStyleArchive.sheet_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_style', full_name='TN.CommandSheetSetStyleArchive.sheet_style', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_sheet_style', full_name='TN.CommandSheetSetStyleArchive.old_sheet_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6247,
  serialized_end=6419,
)


_DOCUMENTSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='DocumentSelectionTransformerArchive',
  full_name='TN.DocumentSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='document_selection', full_name='TN.DocumentSelectionTransformerArchive.document_selection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6421,
  serialized_end=6502,
)


_SHEETSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='SheetSelectionTransformerArchive',
  full_name='TN.SheetSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet_uuid', full_name='TN.SheetSelectionTransformerArchive.sheet_uuid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paginated', full_name='TN.SheetSelectionTransformerArchive.paginated', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6504,
  serialized_end=6588,
)


_FORMSHEETSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='FormSheetSelectionTransformerArchive',
  full_name='TN.FormSheetSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.FormSheetSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_uuid', full_name='TN.FormSheetSelectionTransformerArchive.table_uuid', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6590,
  serialized_end=6712,
)


_CANVASSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='CanvasSelectionTransformerArchive',
  full_name='TN.CanvasSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformer_helper', full_name='TN.CanvasSelectionTransformerArchive.transformer_helper', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_storage_uuid_path', full_name='TN.CanvasSelectionTransformerArchive.header_storage_uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6715,
  serialized_end=6881,
)


_FORMTABLECHOOSERSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='FormTableChooserSelectionTransformerArchive',
  full_name='TN.FormTableChooserSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6883,
  serialized_end=6928,
)


_FORMBUILDERSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='FormBuilderSelectionTransformerArchive',
  full_name='TN.FormBuilderSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uuid', full_name='TN.FormBuilderSelectionTransformerArchive.table_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='viewing_record_uuid', full_name='TN.FormBuilderSelectionTransformerArchive.viewing_record_uuid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='editing_field_uuid', full_name='TN.FormBuilderSelectionTransformerArchive.editing_field_uuid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6931,
  serialized_end=7081,
)


_FORMVIEWERSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='FormViewerSelectionTransformerArchive',
  full_name='TN.FormViewerSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_uuid', full_name='TN.FormViewerSelectionTransformerArchive.table_uuid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record_uuid', full_name='TN.FormViewerSelectionTransformerArchive.record_uuid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='field_uuid', full_name='TN.FormViewerSelectionTransformerArchive.field_uuid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7084,
  serialized_end=7217,
)


_SHEETCHANGEBASEARCHIVE = _descriptor.Descriptor(
  name='SheetChangeBaseArchive',
  full_name='TN.SheetChangeBaseArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sheet_id', full_name='TN.SheetChangeBaseArchive.sheet_id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7219,
  serialized_end=7272,
)


_SHEETCHANGESHEETNAMEARCHIVE = _descriptor.Descriptor(
  name='SheetChangeSheetNameArchive',
  full_name='TN.SheetChangeSheetNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.SheetChangeSheetNameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_name', full_name='TN.SheetChangeSheetNameArchive.sheet_name', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7274,
  serialized_end=7366,
)


_COMMANDINDUCEDSHEETCHANGEARCHIVE = _descriptor.Descriptor(
  name='CommandInducedSheetChangeArchive',
  full_name='TN.CommandInducedSheetChangeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TN.CommandInducedSheetChangeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sheet_changes', full_name='TN.CommandInducedSheetChangeArchive.sheet_changes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7368,
  serialized_end=7494,
)

_COMMANDFORMCHOOSETARGETTABLEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDFORMCHOOSETARGETTABLEARCHIVE.fields_by_name['table_id'].message_type = TSPMessages__pb2._UUID
_COMMANDFORMCHOOSETARGETTABLEARCHIVE.fields_by_name['previous_table_id'].message_type = TSPMessages__pb2._UUID
_COMMANDFORMCHOOSETARGETTABLEARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['drawable_undo_object'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['formula_rewrite_command_for_undo'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['chart_entity_uid_for_backing_tables'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETINSERTDRAWABLESARCHIVE.fields_by_name['backing_tables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['drawables'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['chart_entity_uid_for_backing_tables'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETREMOVEDRAWABLESARCHIVE.fields_by_name['backing_table_uids'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE.fields_by_name['args_list'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['argsList'].message_type = TSKArchives__pb2._ADDIDOPERATIONARGS
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['sheets'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['custom_format_keys'].message_type = TSPMessages__pb2._UUID
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['drawable_undo_object'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDOCUMENTINSERTSHEETARCHIVE.fields_by_name['sheet_uistates'].message_type = TNArchives__pb2._UUIDSHEETUISTATEDICTIONARYARCHIVE
_COMMANDDOCUMENTREMOVESHEETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDDOCUMENTREMOVESHEETARCHIVE.fields_by_name['argsList'].message_type = TSKArchives__pb2._REMOVEIDOPERATIONARGS
_COMMANDDOCUMENTREMOVESHEETARCHIVE.fields_by_name['sheets'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDOCUMENTREMOVESHEETARCHIVE.fields_by_name['sheet_uistates'].message_type = TNArchives__pb2._UUIDSHEETUISTATEDICTIONARYARCHIVE
_COMMANDDOCUMENTREORDERSHEETARCHIVE.fields_by_name['argsList'].message_type = TSKArchives__pb2._REARRANGEIDOPERATIONARGS
_COMMANDDOCUMENTREORDERSHEETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSHEETNAMEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSHEETNAMEARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETSHEETSHOULDPRINTCOMMENTSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSHEETSHOULDPRINTCOMMENTSARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETSHEETDIRECTIONARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSHEETDIRECTIONARCHIVE.fields_by_name['newDirection'].enum_type = TNArchives__pb2._PAGELAYOUTDIRECTION
_COMMANDSETSHEETDIRECTIONARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETSHEETDIRECTIONARCHIVE.fields_by_name['oldDirection'].enum_type = TNArchives__pb2._PAGELAYOUTDIRECTION
_COMMANDSETPAGEORIENTATIONARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETPAGEORIENTATIONARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSHOWPAGENUMBERSVALUEARCHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETSHOWPAGENUMBERSVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETREPEATINGHEADERSVALUEARCHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETREPEATINGHEADERSVALUEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETCONTENTSCALEARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCONTENTSCALEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETDOCUMENTPAPERSIZE.fields_by_name['page_size'].message_type = TSPMessages__pb2._SIZE
_COMMANDSETDOCUMENTPAPERSIZE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETDOCUMENTPAPERSIZE.fields_by_name['old_page_size'].message_type = TSPMessages__pb2._SIZE
_COMMANDENTERPRINTPREVIEWMODEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDEXITPRINTPREVIEWMODEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETPRINTERMARGINSARCHIVE.fields_by_name['new_print_margins'].message_type = TSDArchives__pb2._EDGEINSETSARCHIVE
_COMMANDSETPRINTERMARGINSARCHIVE.fields_by_name['old_print_margins'].message_type = TSDArchives__pb2._EDGEINSETSARCHIVE
_COMMANDSETPRINTERMARGINSARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETPRINTERMARGINSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETPRINTBACKGROUNDSARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETPRINTBACKGROUNDSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETHEADERFOOTERINSETSARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETHEADERFOOTERINSETSARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETPAGEORDERARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETPAGEORDERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETUSINGSTARTPAGENUMBERARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETUSINGSTARTPAGENUMBERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSETSTARTPAGENUMBERARCHIVE.fields_by_name['sheet_uid'].message_type = TSPMessages__pb2._UUID
_COMMANDSETSTARTPAGENUMBERARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREORDERSIDEBARITEMCHILDRENACHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREORDERSIDEBARITEMCHILDRENACHIVE.fields_by_name['sheet'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREORDERSIDEBARITEMCHILDRENACHIVE.fields_by_name['old_children'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREORDERSIDEBARITEMCHILDRENACHIVE.fields_by_name['new_children'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTMEDIATORSETEDITINGSTATE.fields_by_name['super'].message_type = TSCHCommandArchives__pb2._CHARTCOMMANDARCHIVE
_COMMANDCHARTMEDIATORSETEDITINGSTATE.fields_by_name['old_formulas'].message_type = TNArchives__pb2._CHARTMEDIATORFORMULASTORAGE
_COMMANDCHARTMEDIATORSETEDITINGSTATE.fields_by_name['new_formulas'].message_type = TNArchives__pb2._CHARTMEDIATORFORMULASTORAGE
_COMMANDCHARTMEDIATORSETGRIDDIRECTION.fields_by_name['super'].message_type = TSCHCommandArchives__pb2._CHARTCOMMANDARCHIVE
_COMMANDCHARTMEDIATORSETGRIDDIRECTION.fields_by_name['old_formula_storage'].message_type = TNArchives__pb2._CHARTMEDIATORFORMULASTORAGE
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['super'].message_type = TSCHCommandArchives__pb2._CHARTCOMMANDARCHIVE
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['series_id'].message_type = TSPMessages__pb2._UUID
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['preceding_series_id'].message_type = TSPMessages__pb2._UUID
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['inverse_series_id'].message_type = TSPMessages__pb2._UUID
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['inverse_preceding_series_id'].message_type = TSPMessages__pb2._UUID
_COMMANDCHARTMEDIATORSETSERIESORDER.fields_by_name['old_formula_storage'].message_type = TNArchives__pb2._CHARTMEDIATORFORMULASTORAGE
_COMMANDCHARTMEDIATORUPDATEFORENTITYDELETE.fields_by_name['super'].message_type = TSCHCommandArchives__pb2._CHARTCOMMANDARCHIVE
_COMMANDCHARTMEDIATORUPDATEFORENTITYDELETE.fields_by_name['cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTMEDIATORSETFORMULA.fields_by_name['super'].message_type = TSCHCommandArchives__pb2._CHARTCOMMANDARCHIVE
_COMMANDCHARTMEDIATORSETFORMULA.fields_by_name['formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_COMMANDCHARTMEDIATORSETFORMULA.fields_by_name['old_formulae'].message_type = TSCEArchives__pb2._FORMULAARCHIVE
_COMMANDSHEETSETBACKGROUNDFILLARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHEETSETBACKGROUNDFILLARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETSETBACKGROUNDFILLARCHIVE.fields_by_name['new_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_COMMANDSHEETSETBACKGROUNDFILLARCHIVE.fields_by_name['old_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_COMMANDSHEETSETSTYLEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDSHEETSETSTYLEARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_COMMANDSHEETSETSTYLEARCHIVE.fields_by_name['sheet_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSHEETSETSTYLEARCHIVE.fields_by_name['old_sheet_style'].message_type = TSPMessages__pb2._REFERENCE
_DOCUMENTSELECTIONTRANSFORMERARCHIVE.fields_by_name['document_selection'].message_type = TSPMessages__pb2._REFERENCE
_SHEETSELECTIONTRANSFORMERARCHIVE.fields_by_name['sheet_uuid'].message_type = TSPMessages__pb2._UUID
_FORMSHEETSELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = _SHEETSELECTIONTRANSFORMERARCHIVE
_FORMSHEETSELECTIONTRANSFORMERARCHIVE.fields_by_name['table_uuid'].message_type = TSPMessages__pb2._UUID
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['transformer_helper'].message_type = TSDCommandArchives__pb2._INFOCOLLECTIONSELECTIONTRANSFORMERHELPERARCHIVE
_CANVASSELECTIONTRANSFORMERARCHIVE.fields_by_name['header_storage_uuid_path'].message_type = TSPMessages__pb2._UUIDPATH
_FORMBUILDERSELECTIONTRANSFORMERARCHIVE.fields_by_name['table_uuid'].message_type = TSPMessages__pb2._UUID
_FORMBUILDERSELECTIONTRANSFORMERARCHIVE.fields_by_name['viewing_record_uuid'].message_type = TSPMessages__pb2._UUID
_FORMBUILDERSELECTIONTRANSFORMERARCHIVE.fields_by_name['editing_field_uuid'].message_type = TSPMessages__pb2._UUID
_FORMVIEWERSELECTIONTRANSFORMERARCHIVE.fields_by_name['table_uuid'].message_type = TSPMessages__pb2._UUID
_FORMVIEWERSELECTIONTRANSFORMERARCHIVE.fields_by_name['record_uuid'].message_type = TSPMessages__pb2._UUID
_FORMVIEWERSELECTIONTRANSFORMERARCHIVE.fields_by_name['field_uuid'].message_type = TSPMessages__pb2._UUID
_SHEETCHANGEBASEARCHIVE.fields_by_name['sheet_id'].message_type = TSPMessages__pb2._UUID
_SHEETCHANGESHEETNAMEARCHIVE.fields_by_name['super'].message_type = _SHEETCHANGEBASEARCHIVE
_COMMANDINDUCEDSHEETCHANGEARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDINDUCEDSHEETCHANGEARCHIVE.fields_by_name['sheet_changes'].message_type = _SHEETCHANGESHEETNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandFormChooseTargetTableArchive'] = _COMMANDFORMCHOOSETARGETTABLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSheetInsertDrawablesArchive'] = _COMMANDSHEETINSERTDRAWABLESARCHIVE
DESCRIPTOR.message_types_by_name['CommandSheetRemoveDrawablesArchive'] = _COMMANDSHEETREMOVEDRAWABLESARCHIVE
DESCRIPTOR.message_types_by_name['CommandSheetMoveDrawableZOrderArchive'] = _COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE
DESCRIPTOR.message_types_by_name['CommandDocumentInsertSheetArchive'] = _COMMANDDOCUMENTINSERTSHEETARCHIVE
DESCRIPTOR.message_types_by_name['CommandDocumentRemoveSheetArchive'] = _COMMANDDOCUMENTREMOVESHEETARCHIVE
DESCRIPTOR.message_types_by_name['CommandDocumentReorderSheetArchive'] = _COMMANDDOCUMENTREORDERSHEETARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSheetNameArchive'] = _COMMANDSETSHEETNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSheetShouldPrintCommentsArchive'] = _COMMANDSETSHEETSHOULDPRINTCOMMENTSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSheetDirectionArchive'] = _COMMANDSETSHEETDIRECTIONARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPageOrientationArchive'] = _COMMANDSETPAGEORIENTATIONARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetShowPageNumbersValueArchive'] = _COMMANDSETSHOWPAGENUMBERSVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetRepeatingHeadersValueArchive'] = _COMMANDSETREPEATINGHEADERSVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetContentScaleArchive'] = _COMMANDSETCONTENTSCALEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetDocumentPaperSize'] = _COMMANDSETDOCUMENTPAPERSIZE
DESCRIPTOR.message_types_by_name['CommandEnterPrintPreviewModeArchive'] = _COMMANDENTERPRINTPREVIEWMODEARCHIVE
DESCRIPTOR.message_types_by_name['CommandExitPrintPreviewModeArchive'] = _COMMANDEXITPRINTPREVIEWMODEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPrinterMarginsArchive'] = _COMMANDSETPRINTERMARGINSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPrintBackgroundsArchive'] = _COMMANDSETPRINTBACKGROUNDSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetHeaderFooterInsetsArchive'] = _COMMANDSETHEADERFOOTERINSETSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPageOrderArchive'] = _COMMANDSETPAGEORDERARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetUsingStartPageNumberArchive'] = _COMMANDSETUSINGSTARTPAGENUMBERARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetStartPageNumberArchive'] = _COMMANDSETSTARTPAGENUMBERARCHIVE
DESCRIPTOR.message_types_by_name['CommandReorderSidebarItemChildrenAchive'] = _COMMANDREORDERSIDEBARITEMCHILDRENACHIVE
DESCRIPTOR.message_types_by_name['CommandChartMediatorSetEditingState'] = _COMMANDCHARTMEDIATORSETEDITINGSTATE
DESCRIPTOR.message_types_by_name['CommandChartMediatorSetGridDirection'] = _COMMANDCHARTMEDIATORSETGRIDDIRECTION
DESCRIPTOR.message_types_by_name['CommandChartMediatorSetSeriesOrder'] = _COMMANDCHARTMEDIATORSETSERIESORDER
DESCRIPTOR.message_types_by_name['CommandChartMediatorUpdateForEntityDelete'] = _COMMANDCHARTMEDIATORUPDATEFORENTITYDELETE
DESCRIPTOR.message_types_by_name['CommandChartMediatorSetFormula'] = _COMMANDCHARTMEDIATORSETFORMULA
DESCRIPTOR.message_types_by_name['CommandSheetSetBackgroundFillArchive'] = _COMMANDSHEETSETBACKGROUNDFILLARCHIVE
DESCRIPTOR.message_types_by_name['CommandSheetSetStyleArchive'] = _COMMANDSHEETSETSTYLEARCHIVE
DESCRIPTOR.message_types_by_name['DocumentSelectionTransformerArchive'] = _DOCUMENTSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['SheetSelectionTransformerArchive'] = _SHEETSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['FormSheetSelectionTransformerArchive'] = _FORMSHEETSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['CanvasSelectionTransformerArchive'] = _CANVASSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['FormTableChooserSelectionTransformerArchive'] = _FORMTABLECHOOSERSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['FormBuilderSelectionTransformerArchive'] = _FORMBUILDERSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['FormViewerSelectionTransformerArchive'] = _FORMVIEWERSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['SheetChangeBaseArchive'] = _SHEETCHANGEBASEARCHIVE
DESCRIPTOR.message_types_by_name['SheetChangeSheetNameArchive'] = _SHEETCHANGESHEETNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandInducedSheetChangeArchive'] = _COMMANDINDUCEDSHEETCHANGEARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CommandFormChooseTargetTableArchive = _reflection.GeneratedProtocolMessageType('CommandFormChooseTargetTableArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDFORMCHOOSETARGETTABLEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandFormChooseTargetTableArchive)
  })
_sym_db.RegisterMessage(CommandFormChooseTargetTableArchive)

CommandSheetInsertDrawablesArchive = _reflection.GeneratedProtocolMessageType('CommandSheetInsertDrawablesArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSHEETINSERTDRAWABLESARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSheetInsertDrawablesArchive)
  })
_sym_db.RegisterMessage(CommandSheetInsertDrawablesArchive)

CommandSheetRemoveDrawablesArchive = _reflection.GeneratedProtocolMessageType('CommandSheetRemoveDrawablesArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSHEETREMOVEDRAWABLESARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSheetRemoveDrawablesArchive)
  })
_sym_db.RegisterMessage(CommandSheetRemoveDrawablesArchive)

CommandSheetMoveDrawableZOrderArchive = _reflection.GeneratedProtocolMessageType('CommandSheetMoveDrawableZOrderArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSHEETMOVEDRAWABLEZORDERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSheetMoveDrawableZOrderArchive)
  })
_sym_db.RegisterMessage(CommandSheetMoveDrawableZOrderArchive)

CommandDocumentInsertSheetArchive = _reflection.GeneratedProtocolMessageType('CommandDocumentInsertSheetArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDOCUMENTINSERTSHEETARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandDocumentInsertSheetArchive)
  })
_sym_db.RegisterMessage(CommandDocumentInsertSheetArchive)

CommandDocumentRemoveSheetArchive = _reflection.GeneratedProtocolMessageType('CommandDocumentRemoveSheetArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDOCUMENTREMOVESHEETARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandDocumentRemoveSheetArchive)
  })
_sym_db.RegisterMessage(CommandDocumentRemoveSheetArchive)

CommandDocumentReorderSheetArchive = _reflection.GeneratedProtocolMessageType('CommandDocumentReorderSheetArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDDOCUMENTREORDERSHEETARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandDocumentReorderSheetArchive)
  })
_sym_db.RegisterMessage(CommandDocumentReorderSheetArchive)

CommandSetSheetNameArchive = _reflection.GeneratedProtocolMessageType('CommandSetSheetNameArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETSHEETNAMEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetSheetNameArchive)
  })
_sym_db.RegisterMessage(CommandSetSheetNameArchive)

CommandSetSheetShouldPrintCommentsArchive = _reflection.GeneratedProtocolMessageType('CommandSetSheetShouldPrintCommentsArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETSHEETSHOULDPRINTCOMMENTSARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetSheetShouldPrintCommentsArchive)
  })
_sym_db.RegisterMessage(CommandSetSheetShouldPrintCommentsArchive)

CommandSetSheetDirectionArchive = _reflection.GeneratedProtocolMessageType('CommandSetSheetDirectionArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETSHEETDIRECTIONARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetSheetDirectionArchive)
  })
_sym_db.RegisterMessage(CommandSetSheetDirectionArchive)

CommandSetPageOrientationArchive = _reflection.GeneratedProtocolMessageType('CommandSetPageOrientationArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETPAGEORIENTATIONARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetPageOrientationArchive)
  })
_sym_db.RegisterMessage(CommandSetPageOrientationArchive)

CommandSetShowPageNumbersValueArchive = _reflection.GeneratedProtocolMessageType('CommandSetShowPageNumbersValueArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETSHOWPAGENUMBERSVALUEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetShowPageNumbersValueArchive)
  })
_sym_db.RegisterMessage(CommandSetShowPageNumbersValueArchive)

CommandSetRepeatingHeadersValueArchive = _reflection.GeneratedProtocolMessageType('CommandSetRepeatingHeadersValueArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETREPEATINGHEADERSVALUEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetRepeatingHeadersValueArchive)
  })
_sym_db.RegisterMessage(CommandSetRepeatingHeadersValueArchive)

CommandSetContentScaleArchive = _reflection.GeneratedProtocolMessageType('CommandSetContentScaleArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETCONTENTSCALEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetContentScaleArchive)
  })
_sym_db.RegisterMessage(CommandSetContentScaleArchive)

CommandSetDocumentPaperSize = _reflection.GeneratedProtocolMessageType('CommandSetDocumentPaperSize', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETDOCUMENTPAPERSIZE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetDocumentPaperSize)
  })
_sym_db.RegisterMessage(CommandSetDocumentPaperSize)

CommandEnterPrintPreviewModeArchive = _reflection.GeneratedProtocolMessageType('CommandEnterPrintPreviewModeArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDENTERPRINTPREVIEWMODEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandEnterPrintPreviewModeArchive)
  })
_sym_db.RegisterMessage(CommandEnterPrintPreviewModeArchive)

CommandExitPrintPreviewModeArchive = _reflection.GeneratedProtocolMessageType('CommandExitPrintPreviewModeArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDEXITPRINTPREVIEWMODEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandExitPrintPreviewModeArchive)
  })
_sym_db.RegisterMessage(CommandExitPrintPreviewModeArchive)

CommandSetPrinterMarginsArchive = _reflection.GeneratedProtocolMessageType('CommandSetPrinterMarginsArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETPRINTERMARGINSARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetPrinterMarginsArchive)
  })
_sym_db.RegisterMessage(CommandSetPrinterMarginsArchive)

CommandSetPrintBackgroundsArchive = _reflection.GeneratedProtocolMessageType('CommandSetPrintBackgroundsArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETPRINTBACKGROUNDSARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetPrintBackgroundsArchive)
  })
_sym_db.RegisterMessage(CommandSetPrintBackgroundsArchive)

CommandSetHeaderFooterInsetsArchive = _reflection.GeneratedProtocolMessageType('CommandSetHeaderFooterInsetsArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETHEADERFOOTERINSETSARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetHeaderFooterInsetsArchive)
  })
_sym_db.RegisterMessage(CommandSetHeaderFooterInsetsArchive)

CommandSetPageOrderArchive = _reflection.GeneratedProtocolMessageType('CommandSetPageOrderArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETPAGEORDERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetPageOrderArchive)
  })
_sym_db.RegisterMessage(CommandSetPageOrderArchive)

CommandSetUsingStartPageNumberArchive = _reflection.GeneratedProtocolMessageType('CommandSetUsingStartPageNumberArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETUSINGSTARTPAGENUMBERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetUsingStartPageNumberArchive)
  })
_sym_db.RegisterMessage(CommandSetUsingStartPageNumberArchive)

CommandSetStartPageNumberArchive = _reflection.GeneratedProtocolMessageType('CommandSetStartPageNumberArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSETSTARTPAGENUMBERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSetStartPageNumberArchive)
  })
_sym_db.RegisterMessage(CommandSetStartPageNumberArchive)

CommandReorderSidebarItemChildrenAchive = _reflection.GeneratedProtocolMessageType('CommandReorderSidebarItemChildrenAchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDREORDERSIDEBARITEMCHILDRENACHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandReorderSidebarItemChildrenAchive)
  })
_sym_db.RegisterMessage(CommandReorderSidebarItemChildrenAchive)

CommandChartMediatorSetEditingState = _reflection.GeneratedProtocolMessageType('CommandChartMediatorSetEditingState', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCHARTMEDIATORSETEDITINGSTATE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandChartMediatorSetEditingState)
  })
_sym_db.RegisterMessage(CommandChartMediatorSetEditingState)

CommandChartMediatorSetGridDirection = _reflection.GeneratedProtocolMessageType('CommandChartMediatorSetGridDirection', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCHARTMEDIATORSETGRIDDIRECTION,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandChartMediatorSetGridDirection)
  })
_sym_db.RegisterMessage(CommandChartMediatorSetGridDirection)

CommandChartMediatorSetSeriesOrder = _reflection.GeneratedProtocolMessageType('CommandChartMediatorSetSeriesOrder', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCHARTMEDIATORSETSERIESORDER,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandChartMediatorSetSeriesOrder)
  })
_sym_db.RegisterMessage(CommandChartMediatorSetSeriesOrder)

CommandChartMediatorUpdateForEntityDelete = _reflection.GeneratedProtocolMessageType('CommandChartMediatorUpdateForEntityDelete', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCHARTMEDIATORUPDATEFORENTITYDELETE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandChartMediatorUpdateForEntityDelete)
  })
_sym_db.RegisterMessage(CommandChartMediatorUpdateForEntityDelete)

CommandChartMediatorSetFormula = _reflection.GeneratedProtocolMessageType('CommandChartMediatorSetFormula', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDCHARTMEDIATORSETFORMULA,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandChartMediatorSetFormula)
  })
_sym_db.RegisterMessage(CommandChartMediatorSetFormula)

CommandSheetSetBackgroundFillArchive = _reflection.GeneratedProtocolMessageType('CommandSheetSetBackgroundFillArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSHEETSETBACKGROUNDFILLARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSheetSetBackgroundFillArchive)
  })
_sym_db.RegisterMessage(CommandSheetSetBackgroundFillArchive)

CommandSheetSetStyleArchive = _reflection.GeneratedProtocolMessageType('CommandSheetSetStyleArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDSHEETSETSTYLEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandSheetSetStyleArchive)
  })
_sym_db.RegisterMessage(CommandSheetSetStyleArchive)

DocumentSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('DocumentSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _DOCUMENTSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.DocumentSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(DocumentSelectionTransformerArchive)

SheetSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('SheetSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(SheetSelectionTransformerArchive)

FormSheetSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('FormSheetSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMSHEETSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormSheetSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(FormSheetSelectionTransformerArchive)

CanvasSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('CanvasSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _CANVASSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CanvasSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(CanvasSelectionTransformerArchive)

FormTableChooserSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('FormTableChooserSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMTABLECHOOSERSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormTableChooserSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(FormTableChooserSelectionTransformerArchive)

FormBuilderSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('FormBuilderSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMBUILDERSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormBuilderSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(FormBuilderSelectionTransformerArchive)

FormViewerSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('FormViewerSelectionTransformerArchive', (_message.Message,), {
  'DESCRIPTOR' : _FORMVIEWERSELECTIONTRANSFORMERARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.FormViewerSelectionTransformerArchive)
  })
_sym_db.RegisterMessage(FormViewerSelectionTransformerArchive)

SheetChangeBaseArchive = _reflection.GeneratedProtocolMessageType('SheetChangeBaseArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETCHANGEBASEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetChangeBaseArchive)
  })
_sym_db.RegisterMessage(SheetChangeBaseArchive)

SheetChangeSheetNameArchive = _reflection.GeneratedProtocolMessageType('SheetChangeSheetNameArchive', (_message.Message,), {
  'DESCRIPTOR' : _SHEETCHANGESHEETNAMEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.SheetChangeSheetNameArchive)
  })
_sym_db.RegisterMessage(SheetChangeSheetNameArchive)

CommandInducedSheetChangeArchive = _reflection.GeneratedProtocolMessageType('CommandInducedSheetChangeArchive', (_message.Message,), {
  'DESCRIPTOR' : _COMMANDINDUCEDSHEETCHANGEARCHIVE,
  '__module__' : 'TNCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TN.CommandInducedSheetChangeArchive)
  })
_sym_db.RegisterMessage(CommandInducedSheetChangeArchive)


# @@protoc_insertion_point(module_scope)
